"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "xss_match_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates an XssMatchSet, which you use to allow, block, or count requests that contain cross-site scripting attacks in the specified part of web requests. AWS WAF searches for character sequences that are likely to be malicious strings. To create and configure an XssMatchSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateXssMatchSet request.   Submit a CreateXssMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateXssMatchSet request.   Submit an UpdateXssMatchSet request to specify the parts of web requests in which you want to allow, block, or count cross-site scripting attacks.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description for the XssMatchSet that you're creating. You can't change Name after you create the XssMatchSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.xss_match_set_.create(
                ctx, name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.xss_match_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_xss_match_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, xss_match_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes an XssMatchSet. You can't delete an XssMatchSet if it's still used in any Rules or if it still contains any XssMatchTuple objects. If you just want to remove an XssMatchSet from a Rule, use UpdateRule. To permanently delete an XssMatchSet from AWS WAF, perform the following steps:   Update the XssMatchSet to remove filters, if any. For more information, see UpdateXssMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteXssMatchSet request.   Submit a DeleteXssMatchSet request.

    Args:
        xss_match_set_id(str): The XssMatchSetId of the XssMatchSet that you want to delete. XssMatchSetId is returned by CreateXssMatchSet and by ListXssMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.xss_match_set_.delete(
                ctx, xss_match_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.xss_match_set.delete xss_match_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_xss_match_set",
        op_kwargs={"XssMatchSetId": xss_match_set_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, xss_match_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the XssMatchSet that is specified by XssMatchSetId.

    Args:
        xss_match_set_id(str): The XssMatchSetId of the XssMatchSet that you want to get. XssMatchSetId is returned by CreateXssMatchSet and by ListXssMatchSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.xss_match_set_.get(ctx, xss_match_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.xss_match_set.get xss_match_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_xss_match_set",
        op_kwargs={"XssMatchSetId": xss_match_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of XssMatchSet objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more XssMatchSet objects than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of XssMatchSets. For the second and subsequent ListXssMatchSets requests, specify the value of NextMarker from the previous response to get information about another batch of XssMatchSets. Defaults to None.
        limit(int, optional): Specifies the number of XssMatchSet objects that you want AWS WAF to return for this request. If you have more XssMatchSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of Rules. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.xss_match_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.xss_match_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_xss_match_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, xss_match_set_id: str, change_token: str, updates: List
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes XssMatchTuple objects (filters) in an XssMatchSet. For each XssMatchTuple object, you specify the following values:    Action: Whether to insert the object into or delete the object from the array. To change an XssMatchTuple, you delete the existing object and add a new one.    FieldToMatch: The part of web requests that you want AWS WAF to inspect and, if you want AWS WAF to inspect a header or custom query parameter, the name of the header or parameter.    TextTransformation: Which text transformation, if any, to perform on the web request before inspecting the request for cross-site scripting attacks. You can only specify a single type of TextTransformation.   You use XssMatchSet objects to specify which CloudFront requests that you want to allow, block, or count. For example, if you're receiving requests that contain cross-site scripting attacks in the request body and you want to block the requests, you can create an XssMatchSet with the applicable settings, and then configure AWS WAF to block the requests.  To create and configure an XssMatchSet, perform the following steps:   Submit a CreateXssMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateIPSet request.   Submit an UpdateXssMatchSet request to specify the parts of web requests that you want AWS WAF to inspect for cross-site scripting attacks.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        xss_match_set_id(str): The XssMatchSetId of the XssMatchSet that you want to update. XssMatchSetId is returned by CreateXssMatchSet and by ListXssMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of XssMatchSetUpdate objects that you want to insert into or delete from an XssMatchSet. For more information, see the applicable data types:    XssMatchSetUpdate: Contains Action and XssMatchTuple     XssMatchTuple: Contains FieldToMatch and TextTransformation     FieldToMatch: Contains Data and Type   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.xss_match_set_.update(
                ctx, xss_match_set_id=value, change_token=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.xss_match_set.update xss_match_set_id=value, change_token=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_xss_match_set",
        op_kwargs={
            "XssMatchSetId": xss_match_set_id,
            "ChangeToken": change_token,
            "Updates": updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Describes a user's SSH information.  Required Permissions: To use this action, an IAM user must have self-management enabled or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.my_user_profile.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.my_user_profile.describe
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="opsworks", operation="describe_my_user_profile", op_kwargs={}
    )


async def update(hub, ctx, ssh_public_key: str = None) -> None:
    r"""
    **Autogenerated function**

    Updates a user's SSH public key.  Required Permissions: To use this action, an IAM user must have self-management enabled or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        ssh_public_key(str, optional): The user's SSH public key. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.my_user_profile.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.my_user_profile.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_my_user_profile",
        op_kwargs={"SshPublicKey": ssh_public_key},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, certificate_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a registered CA certificate.

    Args:
        certificate_id(str): The ID of the certificate to delete. (The last part of the certificate ARN contains the certificate ID.).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ca.certificate.delete(ctx, certificate_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ca.certificate.delete certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_ca_certificate",
        op_kwargs={"certificateId": certificate_id},
    )


async def describe(hub, ctx, certificate_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a registered CA certificate.

    Args:
        certificate_id(str): The CA certificate identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ca.certificate.describe(ctx, certificate_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ca.certificate.describe certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_ca_certificate",
        op_kwargs={"certificateId": certificate_id},
    )


async def list_all(
    hub, ctx, page_size: int = None, marker: str = None, ascending_order: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the CA certificates registered for your AWS account. The results are paginated with a default page size of 25. You can use the returned marker to retrieve additional results.

    Args:
        page_size(int, optional): The result page size. Defaults to None.
        marker(str, optional): The marker for the next set of results. Defaults to None.
        ascending_order(bool, optional): Determines the order of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ca.certificate.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ca.certificate.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_ca_certificates",
        op_kwargs={
            "pageSize": page_size,
            "marker": marker,
            "ascendingOrder": ascending_order,
        },
    )


async def register(
    hub,
    ctx,
    ca_certificate: str,
    verification_certificate: str,
    set_as_active: bool = None,
    allow_auto_registration: bool = None,
    registration_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a CA certificate with AWS IoT. This CA certificate can then be used to sign device certificates, which can be then registered with AWS IoT. You can register up to 10 CA certificates per AWS account that have the same subject field. This enables you to have up to 10 certificate authorities sign your device certificates. If you have more than one CA certificate registered, make sure you pass the CA certificate when you register your device certificates with the RegisterCertificate API.

    Args:
        ca_certificate(str): The CA certificate.
        verification_certificate(str): The private key verification certificate.
        set_as_active(bool, optional): A boolean value that specifies if the CA certificate is set to active. Defaults to None.
        allow_auto_registration(bool, optional): Allows this CA certificate to be used for auto registration of device certificates. Defaults to None.
        registration_config(Dict, optional): Information about the registration configuration. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the CA certificate.  For URI Request parameters use format: ...key1=value1&key2=value2... For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..." For the cli-input-json file use format: "tags": "key1=value1&key2=value2..." . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ca.certificate.register(
                ctx, ca_certificate=value, verification_certificate=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ca.certificate.register ca_certificate=value, verification_certificate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="register_ca_certificate",
        op_kwargs={
            "caCertificate": ca_certificate,
            "verificationCertificate": verification_certificate,
            "setAsActive": set_as_active,
            "allowAutoRegistration": allow_auto_registration,
            "registrationConfig": registration_config,
            "tags": tags,
        },
    )


async def update(
    hub,
    ctx,
    certificate_id: str,
    new_status: str = None,
    new_auto_registration_status: str = None,
    registration_config: Dict = None,
    remove_auto_registration: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a registered CA certificate.

    Args:
        certificate_id(str): The CA certificate identifier.
        new_status(str, optional): The updated status of the CA certificate.  Note: The status value REGISTER_INACTIVE is deprecated and should not be used. Defaults to None.
        new_auto_registration_status(str, optional): The new value for the auto registration status. Valid values are: "ENABLE" or "DISABLE". Defaults to None.
        registration_config(Dict, optional): Information about the registration configuration. Defaults to None.
        remove_auto_registration(bool, optional): If true, removes auto registration. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ca.certificate.update(ctx, certificate_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ca.certificate.update certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_ca_certificate",
        op_kwargs={
            "certificateId": certificate_id,
            "newStatus": new_status,
            "newAutoRegistrationStatus": new_auto_registration_status,
            "registrationConfig": registration_config,
            "removeAutoRegistration": remove_auto_registration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    workbook_id: str,
    table_id: str,
    rows_to_create: List,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The BatchCreateTableRows API allows you to create one or more rows at the end of a table in a workbook. The API allows you to specify the values to set in some or all of the columns in the new rows.   If a column is not explicitly set in a specific row, then the column level formula specified in the table will be applied to the new row. If there is no column level formula but the last row of the table has a formula, then that formula will be copied down to the new row. If there is no column level formula and no formula in the last row of the table, then that column will be left blank for the new rows.

    Args:
        workbook_id(str): The ID of the workbook where the new rows are being added.  If a workbook with the specified ID could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table where the new rows are being added.  If a table with the specified ID could not be found, this API throws ResourceNotFoundException. .
        rows_to_create(List):  The list of rows to create at the end of the table. Each item in this list needs to have a batch item id to uniquely identify the element in the request and the cells to create for that row. You need to specify at least one item in this list.   Note that if one of the column ids in any of the rows in the request does not exist in the table, then the request fails and no updates are made to the table. .
        client_request_token(str, optional):  The request token for performing the batch create operation. Request tokens help to identify duplicate requests. If a call times out or fails due to a transient error like a failed network connection, you can retry the call with the same request token. The service ensures that if the first call using that request token is successfully performed, the second call will not perform the operation again.   Note that request tokens are valid only for a few minutes. You cannot use request tokens to dedupe requests spanning hours or days. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.create_table_row.batch(
                ctx, workbook_id=value, table_id=value, rows_to_create=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.create_table_row.batch workbook_id=value, table_id=value, rows_to_create=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="batch_create_table_rows",
        op_kwargs={
            "workbookId": workbook_id,
            "tableId": table_id,
            "rowsToCreate": rows_to_create,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    cdi_input_specification: Dict = None,
    channel_class: str = None,
    destinations: List = None,
    encoder_settings: Dict = None,
    input_attachments: List = None,
    input_specification: Dict = None,
    log_level: str = None,
    name: str = None,
    request_id: str = None,
    reserved: str = None,
    role_arn: str = None,
    tags: Dict = None,
    vpc: Dict = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Creates a new channel

        Args:
            cdi_input_specification(Dict, optional): Specification of CDI inputs for this channel. Defaults to None.
            channel_class(str, optional): The class for this channel. STANDARD for a channel with two pipelines or SINGLE_PIPELINE for a channel with one pipeline. Defaults to None.
            destinations(List, optional): Placeholder documentation for __listOfOutputDestination. Defaults to None.
            encoder_settings(Dict, optional): Encoder Settings. Defaults to None.
            input_attachments(List, optional): List of input attachments for channel. Defaults to None.
            input_specification(Dict, optional): Specification of network and file inputs for this channel. Defaults to None.
            log_level(str, optional): The log level to write to CloudWatch Logs. Defaults to None.
            name(str, optional): Name of channel. Defaults to None.
            request_id(str, optional): Unique request ID to be specified. This is needed to prevent retries from
    creating multiple resources.
    . Defaults to None.
            reserved(str, optional): Deprecated field that's only usable by whitelisted customers. Defaults to None.
            role_arn(str, optional): An optional Amazon Resource Name (ARN) of the role to assume when running the Channel. Defaults to None.
            tags(Dict, optional): A collection of key-value pairs. Defaults to None.
            vpc(Dict, optional): Settings for VPC output. Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.medialive.channel.init.create(ctx)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.medialive.channel.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="create_channel",
        op_kwargs={
            "CdiInputSpecification": cdi_input_specification,
            "ChannelClass": channel_class,
            "Destinations": destinations,
            "EncoderSettings": encoder_settings,
            "InputAttachments": input_attachments,
            "InputSpecification": input_specification,
            "LogLevel": log_level,
            "Name": name,
            "RequestId": request_id,
            "Reserved": reserved,
            "RoleArn": role_arn,
            "Tags": tags,
            "Vpc": vpc,
        },
    )


async def delete(hub, ctx, channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts deletion of channel. The associated outputs are also deleted.

    Args:
        channel_id(str): Unique ID of the channel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.channel.init.delete(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.channel.init.delete channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="delete_channel",
        op_kwargs={"ChannelId": channel_id},
    )


async def describe(hub, ctx, channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details about a channel

    Args:
        channel_id(str): channel ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.channel.init.describe(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.channel.init.describe channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_channel",
        op_kwargs={"ChannelId": channel_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Produces list of channels that have been created

    Args:
        max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
        next_token(str, optional): Placeholder documentation for __string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.channel.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.channel.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_channels",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def start(hub, ctx, channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts an existing channel

    Args:
        channel_id(str): A request to start a channel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.channel.init.start(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.channel.init.start channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="start_channel",
        op_kwargs={"ChannelId": channel_id},
    )


async def stop(hub, ctx, channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a running channel

    Args:
        channel_id(str): A request to stop a running channel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.channel.init.stop(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.channel.init.stop channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="stop_channel",
        op_kwargs={"ChannelId": channel_id},
    )


async def update(
    hub,
    ctx,
    channel_id: str,
    cdi_input_specification: Dict = None,
    destinations: List = None,
    encoder_settings: Dict = None,
    input_attachments: List = None,
    input_specification: Dict = None,
    log_level: str = None,
    name: str = None,
    role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a channel.

    Args:
        cdi_input_specification(Dict, optional): Specification of CDI inputs for this channel. Defaults to None.
        channel_id(str): channel ID.
        destinations(List, optional): A list of output destinations for this channel. Defaults to None.
        encoder_settings(Dict, optional): The encoder settings for this channel. Defaults to None.
        input_attachments(List, optional): Placeholder documentation for __listOfInputAttachment. Defaults to None.
        input_specification(Dict, optional): Specification of network and file inputs for this channel. Defaults to None.
        log_level(str, optional): The log level to write to CloudWatch Logs. Defaults to None.
        name(str, optional): The name of the channel. Defaults to None.
        role_arn(str, optional): An optional Amazon Resource Name (ARN) of the role to assume when running the Channel. If you do not specify this on an update call but the role was previously set that role will be removed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.channel.init.update(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.channel.init.update channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="update_channel",
        op_kwargs={
            "CdiInputSpecification": cdi_input_specification,
            "ChannelId": channel_id,
            "Destinations": destinations,
            "EncoderSettings": encoder_settings,
            "InputAttachments": input_attachments,
            "InputSpecification": input_specification,
            "LogLevel": log_level,
            "Name": name,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    stack_name: str = None,
    change_set_name: str = None,
    template_stage: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the template body for a specified stack. You can get the template for running or deleted stacks. For deleted stacks, GetTemplate returns the template for up to 90 days after the stack has been deleted.   If the template does not exist, a ValidationError is returned.

    Args:
        stack_name(str, optional): The name or the unique stack ID that is associated with the stack, which are not always interchangeable:   Running stacks: You can specify either the stack's name or its unique stack ID.   Deleted stacks: You must specify the unique stack ID.   Default: There is no default value. Defaults to None.
        change_set_name(str, optional): The name or Amazon Resource Name (ARN) of a change set for which CloudFormation returns the associated template. If you specify a name, you must also specify the StackName. Defaults to None.
        template_stage(str, optional): For templates that include transforms, the stage of the template that CloudFormation returns. To get the user-submitted template, specify Original. To get the template after CloudFormation has processed all transforms, specify Processed.  If the template doesn't include transforms, Original and Processed return the same template. By default, CloudFormation specifies Processed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.template.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.template.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="get_template",
        op_kwargs={
            "StackName": stack_name,
            "ChangeSetName": change_set_name,
            "TemplateStage": template_stage,
        },
    )


async def validate(
    hub, ctx, template_body: str = None, template_url: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Validates a specified template. CloudFormation first checks if the template is valid JSON. If it isn't, CloudFormation checks if the template is valid YAML. If both these checks fail, CloudFormation returns a template validation error.

    Args:
        template_body(str, optional): Structure containing the template body with a minimum length of 1 byte and a maximum length of 51,200 bytes. For more information, go to Template Anatomy in the CloudFormation User Guide. Conditional: You must pass TemplateURL or TemplateBody. If both are passed, only TemplateBody is used. Defaults to None.
        template_url(str, optional): Location of file containing the template body. The URL must point to a template (max size: 460,800 bytes) that is located in an Amazon S3 bucket or a Systems Manager document. For more information, go to Template Anatomy in the CloudFormation User Guide. Conditional: You must pass TemplateURL or TemplateBody. If both are passed, only TemplateBody is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.template.init.validate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.template.init.validate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="validate_template",
        op_kwargs={"TemplateBody": template_body, "TemplateURL": template_url},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns an Amazon S3 presigned URL for an update file associated with a specified JobId.

    Args:
        job_id(str): The ID for a job that you want to get the software update file for, for example JID123e4567-e89b-12d3-a456-426655440000.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.software_update.get_all(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.software_update.get_all job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="get_software_updates",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    authorizer_name: str,
    authorizer_function_arn: str,
    token_key_name: str = None,
    token_signing_public_keys: Dict = None,
    status: str = None,
    tags: List = None,
    signing_disabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an authorizer.

    Args:
        authorizer_name(str): The authorizer name.
        authorizer_function_arn(str): The ARN of the authorizer's Lambda function.
        token_key_name(str, optional): The name of the token key used to extract the token from the HTTP headers. Defaults to None.
        token_signing_public_keys(Dict, optional): The public keys used to verify the digital signature returned by your custom authentication service. Defaults to None.
        status(str, optional): The status of the create authorizer request. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the custom authorizer.  For URI Request parameters use format: ...key1=value1&key2=value2... For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..." For the cli-input-json file use format: "tags": "key1=value1&key2=value2..." . Defaults to None.
        signing_disabled(bool, optional): Specifies whether AWS IoT validates the token signature in an authorization request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.authorizer.create(
                ctx, authorizer_name=value, authorizer_function_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.authorizer.create authorizer_name=value, authorizer_function_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_authorizer",
        op_kwargs={
            "authorizerName": authorizer_name,
            "authorizerFunctionArn": authorizer_function_arn,
            "tokenKeyName": token_key_name,
            "tokenSigningPublicKeys": token_signing_public_keys,
            "status": status,
            "tags": tags,
            "signingDisabled": signing_disabled,
        },
    )


async def delete(hub, ctx, authorizer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an authorizer.

    Args:
        authorizer_name(str): The name of the authorizer to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.authorizer.delete(ctx, authorizer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.authorizer.delete authorizer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_authorizer",
        op_kwargs={"authorizerName": authorizer_name},
    )


async def describe(hub, ctx, authorizer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an authorizer.

    Args:
        authorizer_name(str): The name of the authorizer to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.authorizer.describe(ctx, authorizer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.authorizer.describe authorizer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_authorizer",
        op_kwargs={"authorizerName": authorizer_name},
    )


async def list_all(
    hub,
    ctx,
    page_size: int = None,
    marker: str = None,
    ascending_order: bool = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the authorizers registered in your account.

    Args:
        page_size(int, optional): The maximum number of results to return at one time. Defaults to None.
        marker(str, optional): A marker used to get the next set of results. Defaults to None.
        ascending_order(bool, optional): Return the list of authorizers in ascending alphabetical order. Defaults to None.
        status(str, optional): The status of the list authorizers request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.authorizer.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.authorizer.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_authorizers",
        op_kwargs={
            "pageSize": page_size,
            "marker": marker,
            "ascendingOrder": ascending_order,
            "status": status,
        },
    )


async def update(
    hub,
    ctx,
    authorizer_name: str,
    authorizer_function_arn: str = None,
    token_key_name: str = None,
    token_signing_public_keys: Dict = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an authorizer.

    Args:
        authorizer_name(str): The authorizer name.
        authorizer_function_arn(str, optional): The ARN of the authorizer's Lambda function. Defaults to None.
        token_key_name(str, optional): The key used to extract the token from the HTTP headers. . Defaults to None.
        token_signing_public_keys(Dict, optional): The public keys used to verify the token signature. Defaults to None.
        status(str, optional): The status of the update authorizer request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.authorizer.update(ctx, authorizer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.authorizer.update authorizer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_authorizer",
        op_kwargs={
            "authorizerName": authorizer_name,
            "authorizerFunctionArn": authorizer_function_arn,
            "tokenKeyName": token_key_name,
            "tokenSigningPublicKeys": token_signing_public_keys,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "byte_match_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a ByteMatchSet. You then use UpdateByteMatchSet to identify the part of a web request that you want AWS WAF to inspect, such as the values of the User-Agent header or the query string. For example, you can create a ByteMatchSet that matches any requests with User-Agent headers that contain the string BadBot. You can then configure AWS WAF to reject those requests. To create and configure a ByteMatchSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateByteMatchSet request.   Submit a CreateByteMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateByteMatchSet request.   Submit an UpdateByteMatchSet request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the ByteMatchSet. You can't change Name after you create a ByteMatchSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.byte_match_set_.create(
                ctx, name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.byte_match_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_byte_match_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, byte_match_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a ByteMatchSet. You can't delete a ByteMatchSet if it's still used in any Rules or if it still includes any ByteMatchTuple objects (any filters). If you just want to remove a ByteMatchSet from a Rule, use UpdateRule. To permanently delete a ByteMatchSet, perform the following steps:   Update the ByteMatchSet to remove filters, if any. For more information, see UpdateByteMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteByteMatchSet request.   Submit a DeleteByteMatchSet request.

    Args:
        byte_match_set_id(str): The ByteMatchSetId of the ByteMatchSet that you want to delete. ByteMatchSetId is returned by CreateByteMatchSet and by ListByteMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.byte_match_set_.delete(
                ctx, byte_match_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.byte_match_set.delete byte_match_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_byte_match_set",
        op_kwargs={"ByteMatchSetId": byte_match_set_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, byte_match_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the ByteMatchSet specified by ByteMatchSetId.

    Args:
        byte_match_set_id(str): The ByteMatchSetId of the ByteMatchSet that you want to get. ByteMatchSetId is returned by CreateByteMatchSet and by ListByteMatchSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.byte_match_set_.get(ctx, byte_match_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.byte_match_set.get byte_match_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_byte_match_set",
        op_kwargs={"ByteMatchSetId": byte_match_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of ByteMatchSetSummary objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more ByteMatchSets than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of ByteMatchSets. For the second and subsequent ListByteMatchSets requests, specify the value of NextMarker from the previous response to get information about another batch of ByteMatchSets. Defaults to None.
        limit(int, optional): Specifies the number of ByteMatchSet objects that you want AWS WAF to return for this request. If you have more ByteMatchSets objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of ByteMatchSet objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.byte_match_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.byte_match_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_byte_match_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, byte_match_set_id: str, change_token: str, updates: List
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes ByteMatchTuple objects (filters) in a ByteMatchSet. For each ByteMatchTuple object, you specify the following values:    Whether to insert or delete the object from the array. If you want to change a ByteMatchSetUpdate object, you delete the existing object and add a new one.   The part of a web request that you want AWS WAF to inspect, such as a query string or the value of the User-Agent header.    The bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to look for. For more information, including how you specify the values for the AWS WAF API and the AWS CLI or SDKs, see TargetString in the ByteMatchTuple data type.    Where to look, such as at the beginning or the end of a query string.   Whether to perform any conversions on the request, such as converting it to lowercase, before inspecting it for the specified string.   For example, you can add a ByteMatchSetUpdate object that matches web requests in which User-Agent headers contain the string BadBot. You can then configure AWS WAF to block those requests. To create and configure a ByteMatchSet, perform the following steps:   Create a ByteMatchSet. For more information, see CreateByteMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateByteMatchSet request.   Submit an UpdateByteMatchSet request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        byte_match_set_id(str): The ByteMatchSetId of the ByteMatchSet that you want to update. ByteMatchSetId is returned by CreateByteMatchSet and by ListByteMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of ByteMatchSetUpdate objects that you want to insert into or delete from a ByteMatchSet. For more information, see the applicable data types:    ByteMatchSetUpdate: Contains Action and ByteMatchTuple     ByteMatchTuple: Contains FieldToMatch, PositionalConstraint, TargetString, and TextTransformation     FieldToMatch: Contains Data and Type   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.byte_match_set_.update(
                ctx, byte_match_set_id=value, change_token=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.byte_match_set.update byte_match_set_id=value, change_token=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_byte_match_set",
        op_kwargs={
            "ByteMatchSetId": byte_match_set_id,
            "ChangeToken": change_token,
            "Updates": updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, application_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more applications. The maximum number of applications that can be returned is 100.

    Args:
        application_names(List): A list of application names separated by spaces. The maximum number of application names you can specify is 100.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.get.application.init.batch(
                ctx, application_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.get.application.init.batch application_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="batch_get_applications",
        op_kwargs={"applicationNames": application_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, hit_id: str, expire_at: str) -> Dict:
    r"""
    **Autogenerated function**

     The UpdateExpirationForHIT operation allows you update the expiration time of a HIT. If you update it to a time in the past, the HIT will be immediately expired.

    Args:
        hit_id(str):  The HIT to update. .
        expire_at(str):  The date and time at which you want the HIT to expire .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.expiration_for_hit.update(
                ctx, hit_id=value, expire_at=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.expiration_for_hit.update hit_id=value, expire_at=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="update_expiration_for_hit",
        op_kwargs={"HITId": hit_id, "ExpireAt": expire_at},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(hub, ctx, delivery_stream_name: str, record: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Writes a single data record into an Amazon Kinesis Data Firehose delivery stream. To write multiple data records into a delivery stream, use PutRecordBatch. Applications using these operations are referred to as producers. By default, each delivery stream can take in up to 2,000 transactions per second, 5,000 records per second, or 5 MB per second. If you use PutRecord and PutRecordBatch, the limits are an aggregate across these two operations for each delivery stream. For more information about limits and how to request an increase, see Amazon Kinesis Data Firehose Limits.  You must specify the name of the delivery stream and the data record when using PutRecord. The data record consists of a data blob that can be up to 1,000 KB in size, and any kind of data. For example, it can be a segment from a log file, geographic location data, website clickstream data, and so on. Kinesis Data Firehose buffers records before delivering them to the destination. To disambiguate the data blobs at the destination, a common solution is to use delimiters in the data, such as a newline (\n) or some other character unique within the data. This allows the consumer application to parse individual data items when reading the data from the destination. The PutRecord operation returns a RecordId, which is a unique string assigned to each record. Producer applications can use this ID for purposes such as auditability and investigation. If the PutRecord operation throws a ServiceUnavailableException, back off and retry. If the exception persists, it is possible that the throughput limits have been exceeded for the delivery stream.  Data records sent to Kinesis Data Firehose are stored for 24 hours from the time they are added to a delivery stream as it tries to send the records to the destination. If the destination is unreachable for more than 24 hours, the data is no longer available.  Don't concatenate two or more base64 strings to form the data fields of your records. Instead, concatenate the raw data, then perform base64 encoding.

    Args:
        delivery_stream_name(str): The name of the delivery stream.
        record(Dict): The record.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.record.init.put(
                ctx, delivery_stream_name=value, record=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.record.init.put delivery_stream_name=value, record=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="put_record",
        op_kwargs={"DeliveryStreamName": delivery_stream_name, "Record": record},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assign(
    hub,
    ctx,
    network_interface_id: str,
    allow_reassignment: bool = None,
    private_ip_addresses: List = None,
    secondary_private_ip_address_count: int = None,
    ipv4_prefixes: List = None,
    ipv4_prefix_count: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more secondary private IP addresses to the specified network interface. You can specify one or more specific secondary IP addresses, or you can specify the number of secondary IP addresses to be automatically assigned within the subnet's CIDR block range. The number of secondary IP addresses that you can assign to an instance varies by instance type. For information about instance types, see Instance Types in the Amazon Elastic Compute Cloud User Guide. For more information about Elastic IP addresses, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. When you move a secondary private IP address to another network interface, any Elastic IP address that is associated with the IP address is also moved. Remapping an IP address is an asynchronous operation. When you move an IP address from one network interface to another, check network/interfaces/macs/mac/local-ipv4s in the instance metadata to confirm that the remapping is complete. You must specify either the IP addresses or the IP address count in the request. You can optionally use Prefix Delegation on the network interface. You must specify either the IPv4 Prefix Delegation prefixes, or the IPv4 Prefix Delegation count. For information, see Prefix Delegation in the Amazon Elastic Compute Cloud User Guide.

    Args:
        allow_reassignment(bool, optional): Indicates whether to allow an IP address that is already assigned to another network interface or instance to be reassigned to the specified network interface. Defaults to None.
        network_interface_id(str): The ID of the network interface.
        private_ip_addresses(List, optional): One or more IP addresses to be assigned as a secondary private IP address to the network interface. You can't specify this parameter when also specifying a number of secondary IP addresses. If you don't specify an IP address, Amazon EC2 automatically selects an IP address within the subnet range. Defaults to None.
        secondary_private_ip_address_count(int, optional): The number of secondary IP addresses to assign to the network interface. You can't specify this parameter when also specifying private IP addresses. Defaults to None.
        ipv4_prefixes(List, optional): One or more IPv4 Prefix Delegation prefixes assigned to the network interface. You cannot use this option if you use the Ipv4PrefixCount option. Defaults to None.
        ipv4_prefix_count(int, optional): The number of IPv4 Prefix Delegation prefixes that AWS automatically assigns to the network interface. You cannot use this option if you use the Ipv4 Prefixes option. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.private_ip_address.assign(ctx, network_interface_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.private_ip_address.assign network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="assign_private_ip_addresses",
        op_kwargs={
            "AllowReassignment": allow_reassignment,
            "NetworkInterfaceId": network_interface_id,
            "PrivateIpAddresses": private_ip_addresses,
            "SecondaryPrivateIpAddressCount": secondary_private_ip_address_count,
            "Ipv4Prefixes": ipv4_prefixes,
            "Ipv4PrefixCount": ipv4_prefix_count,
        },
    )


async def unassign(
    hub,
    ctx,
    network_interface_id: str,
    private_ip_addresses: List = None,
    ipv4_prefixes: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Unassigns one or more secondary private IP addresses, or IPv4 Prefix Delegation prefixes from a network interface.

    Args:
        network_interface_id(str): The ID of the network interface.
        private_ip_addresses(List, optional): The secondary private IP addresses to unassign from the network interface. You can specify this option multiple times to unassign more than one IP address. Defaults to None.
        ipv4_prefixes(List, optional): The IPv4 Prefix Delegation prefixes to unassign from the network interface. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.private_ip_address.unassign(ctx, network_interface_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.private_ip_address.unassign network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="unassign_private_ip_addresses",
        op_kwargs={
            "NetworkInterfaceId": network_interface_id,
            "PrivateIpAddresses": private_ip_addresses,
            "Ipv4Prefixes": ipv4_prefixes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, account_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Retrieves (queries) aggregated statistical data for all the S3 buckets that Amazon Macie monitors and analyzes.

    Args:
        account_id(str, optional): The unique identifier for the Amazon Web Services account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.bucket.statistic.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.bucket.statistic.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_bucket_statistics",
        op_kwargs={"accountId": account_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, api_id: str, definition: bytes) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new schema to your GraphQL API. This operation is asynchronous. Use to determine when it has completed.

    Args:
        api_id(str): The API ID.
        definition(bytes): The schema definition, in GraphQL schema language format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.schema_creation.init.start(
                ctx, api_id=value, definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.schema_creation.init.start api_id=value, definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="start_schema_creation",
        op_kwargs={"apiId": api_id, "definition": definition},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    window_execution_id: str,
    task_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the individual task executions (one per target) for a particular task run as part of a maintenance window execution.

    Args:
        window_execution_id(str): The ID of the maintenance window execution the task is part of.
        task_id(str): The ID of the specific task in the maintenance window task that should be retrieved.
        filters(List, optional): Optional filters used to scope down the returned task invocations. The supported filter key is STATUS with the corresponding values PENDING, IN_PROGRESS, SUCCESS, FAILED, TIMED_OUT, CANCELLING, and CANCELLED. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.execution.task.invocation.describe_all(
                ctx, window_execution_id=value, task_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.execution.task.invocation.describe_all window_execution_id=value, task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_maintenance_window_execution_task_invocations",
        op_kwargs={
            "WindowExecutionId": window_execution_id,
            "TaskId": task_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(
    hub, ctx, window_execution_id: str, task_id: str, invocation_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a specific task running on a specific target.

    Args:
        window_execution_id(str): The ID of the maintenance window execution for which the task is a part.
        task_id(str): The ID of the specific task in the maintenance window task that should be retrieved. .
        invocation_id(str): The invocation ID to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.execution.task.invocation.get(
                ctx, window_execution_id=value, task_id=value, invocation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.execution.task.invocation.get window_execution_id=value, task_id=value, invocation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_maintenance_window_execution_task_invocation",
        op_kwargs={
            "WindowExecutionId": window_execution_id,
            "TaskId": task_id,
            "InvocationId": invocation_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the human task user interfaces in your account.

    Args:
        creation_time_after(str, optional): A filter that returns only human task user interfaces with a creation time greater than or equal to the specified timestamp. Defaults to None.
        creation_time_before(str, optional): A filter that returns only human task user interfaces that were created before the specified timestamp. Defaults to None.
        sort_order(str, optional): An optional value that specifies whether you want the results sorted in Ascending or Descending order. Defaults to None.
        next_token(str, optional): A token to resume pagination. Defaults to None.
        max_results(int, optional): The total number of items to return. If the total number of available items is more than the value specified in MaxResults, then a NextToken will be provided in the output that you can use to resume pagination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.human_task_uis.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.human_task_uis.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_human_task_uis",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are deleted as well. Tags that you create for Amazon EKS resources do not propagate to any other resources associated with the cluster. For example, if you tag a cluster with this operation, that tag does not automatically propagate to the subnets and nodes associated with the cluster.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to which to add tags. Currently, the supported resources are Amazon EKS clusters and managed node groups.
        tags(Dict): The tags to add to the resource. A tag is an array of key-value pairs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes specified tags from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource from which to delete tags. Currently, the supported resources are Amazon EKS clusters and managed node groups.
        tag_keys(List): The keys of the tags to be removed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of runs for a specified canary.

    Args:
        name(str): The name of the canary that you want to see runs for.
        next_token(str, optional): A token that indicates that there is more data available. You can use this token in a subsequent GetCanaryRuns operation to retrieve the next set of results. Defaults to None.
        max_results(int, optional): Specify this parameter to limit how many runs are returned each time you use the GetCanaryRuns operation. If you omit this parameter, the default of 100 is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.synthetic.canary.run.get_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.synthetic.canary.run.get_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="synthetics",
        operation="get_canary_runs",
        op_kwargs={"Name": name, "NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, rest_api_id: str, resource_id: str, http_method: str
) -> None:
    r"""
    **Autogenerated function**

    Represents a delete integration.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies a delete integration request's resource identifier.
        http_method(str): [Required] Specifies a delete integration request's HTTP method.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.init.delete(
                ctx, rest_api_id=value, resource_id=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.init.delete rest_api_id=value, resource_id=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_integration",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
        },
    )


async def get(hub, ctx, rest_api_id: str, resource_id: str, http_method: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the integration settings.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies a get integration request's resource identifier.
        http_method(str): [Required] Specifies a get integration request's HTTP method.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.init.get(
                ctx, rest_api_id=value, resource_id=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.init.get rest_api_id=value, resource_id=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_integration",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
        },
    )


async def put(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    type_: str,
    integration_http_method: str = None,
    uri: str = None,
    connection_type: str = None,
    connection_id: str = None,
    credentials: str = None,
    request_parameters: Dict = None,
    request_templates: Dict = None,
    passthrough_behavior: str = None,
    cache_namespace: str = None,
    cache_key_parameters: List = None,
    content_handling: str = None,
    timeout_in_millis: int = None,
    tls_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets up a method's integration.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Specifies a put integration request's resource ID.
        http_method(str): [Required] Specifies a put integration request's HTTP method.
        type_(str): [Required] Specifies a put integration input's type.
        integration_http_method(str, optional): Specifies a put integration HTTP method. When the integration type is HTTP or AWS, this field is required. Defaults to None.
        uri(str, optional): Specifies Uniform Resource Identifier (URI) of the integration endpoint.   For HTTP or HTTP_PROXY integrations, the URI must be a fully formed, encoded HTTP(S) URL according to the RFC-3986 specification, for either standard integration, where connectionType is not VPC_LINK, or private integration, where connectionType is VPC_LINK. For a private HTTP integration, the URI is not used for routing.    For AWS or AWS_PROXY integrations, the URI is of the form arn:aws:apigateway:{region}:{subdomain.service|service}:path|action/{service_api}. Here, {Region} is the API Gateway region (e.g., us-east-1); {service} is the name of the integrated AWS service (e.g., s3); and {subdomain} is a designated subdomain supported by certain AWS service for fast host-name lookup. action can be used for an AWS service action-based API, using an Action={name}&{p1}={v1}&p2={v2}... query string. The ensuing {service_api} refers to a supported action {name} plus any required input parameters. Alternatively, path can be used for an AWS service path-based API. The ensuing service_api refers to the path to an AWS service resource, including the region of the integrated AWS service, if applicable. For example, for integration with the S3 API of GetObject, the uri can be either arn:aws:apigateway:us-west-2:s3:action/GetObject&Bucket={bucket}&Key={key} or arn:aws:apigateway:us-west-2:s3:path/{bucket}/{key} . Defaults to None.
        connection_type(str, optional): The type of the network connection to the integration endpoint. The valid value is INTERNET for connections through the public routable internet or VPC_LINK for private connections between API Gateway and a network load balancer in a VPC. The default value is INTERNET. Defaults to None.
        connection_id(str, optional): The (id) of the VpcLink used for the integration when connectionType=VPC_LINK and undefined, otherwise. Defaults to None.
        credentials(str, optional): Specifies whether credentials are required for a put integration. Defaults to None.
        request_parameters(Dict, optional): A key-value map specifying request parameters that are passed from the method request to the back end. The key is an integration request parameter name and the associated value is a method request parameter value or static value that must be enclosed within single quotes and pre-encoded as required by the back end. The method request parameter value must match the pattern of method.request.{location}.{name}, where location is querystring, path, or header and name must be a valid and unique method request parameter name. Defaults to None.
        request_templates(Dict, optional): Represents a map of Velocity templates that are applied on the request payload based on the value of the Content-Type header sent by the client. The content type value is the key in this map, and the template (as a String) is the value. Defaults to None.
        passthrough_behavior(str, optional): Specifies the pass-through behavior for incoming requests based on the Content-Type header in the request, and the available mapping templates specified as the requestTemplates property on the Integration resource. There are three valid values: WHEN_NO_MATCH, WHEN_NO_TEMPLATES, and NEVER.   WHEN_NO_MATCH passes the request body for unmapped content types through to the integration back end without transformation. NEVER rejects unmapped content types with an HTTP 415 'Unsupported Media Type' response. WHEN_NO_TEMPLATES allows pass-through when the integration has NO content types mapped to templates. However if there is at least one content type defined, unmapped content types will be rejected with the same 415 response. . Defaults to None.
        cache_namespace(str, optional): Specifies a group of related cached parameters. By default, API Gateway uses the resource ID as the cacheNamespace. You can specify the same cacheNamespace across resources to return the same cached data for requests to different resources. Defaults to None.
        cache_key_parameters(List, optional): A list of request parameters whose values API Gateway caches. To be valid values for cacheKeyParameters, these parameters must also be specified for Method requestParameters. Defaults to None.
        content_handling(str, optional): Specifies how to handle request payload content type conversions. Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors:  CONVERT_TO_BINARY: Converts a request payload from a Base64-encoded string to the corresponding binary blob. CONVERT_TO_TEXT: Converts a request payload from a binary blob to a Base64-encoded string.  If this property is not defined, the request payload will be passed through from the method request to integration request without modification, provided that the passthroughBehavior is configured to support payload pass-through. Defaults to None.
        timeout_in_millis(int, optional): Custom timeout between 50 and 29,000 milliseconds. The default value is 29,000 milliseconds or 29 seconds. Defaults to None.
        tls_config(Dict, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.init.put(
                ctx, rest_api_id=value, resource_id=value, http_method=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.init.put rest_api_id=value, resource_id=value, http_method=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="put_integration",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "type": type_,
            "integrationHttpMethod": integration_http_method,
            "uri": uri,
            "connectionType": connection_type,
            "connectionId": connection_id,
            "credentials": credentials,
            "requestParameters": request_parameters,
            "requestTemplates": request_templates,
            "passthroughBehavior": passthrough_behavior,
            "cacheNamespace": cache_namespace,
            "cacheKeyParameters": cache_key_parameters,
            "contentHandling": content_handling,
            "timeoutInMillis": timeout_in_millis,
            "tlsConfig": tls_config,
        },
    )


async def update(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    patch_operations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Represents an update integration.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] Represents an update integration request's resource identifier.
        http_method(str): [Required] Represents an update integration request's HTTP method.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.integration.init.update(
                ctx, rest_api_id=value, resource_id=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.integration.init.update rest_api_id=value, resource_id=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_integration",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def upload(
    hub,
    ctx,
    bucket: str,
    copy_source: str,
    key: str,
    part_number: int,
    upload_id: str,
    copy_source_if_match: str = None,
    copy_source_if_modified_since: str = None,
    copy_source_if_none_match: str = None,
    copy_source_if_unmodified_since: str = None,
    copy_source_range: str = None,
    sse_customer_algorithm: str = None,
    sse_customer_key: str = None,
    sse_customer_key_md5: str = None,
    copy_source_sse_customer_algorithm: str = None,
    copy_source_sse_customer_key: str = None,
    copy_source_sse_customer_key_md5: str = None,
    request_payer: str = None,
    expected_bucket_owner: str = None,
    expected_source_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads a part by copying data from an existing object as data source. You specify the data source by adding the request header x-amz-copy-source in your request and a byte range by adding the request header x-amz-copy-source-range in your request.  The minimum allowable part size for a multipart upload is 5 MB. For more information about multipart upload limits, go to Quick Facts in the Amazon S3 User Guide.   Instead of using an existing object as part data, you might use the UploadPart action and provide data in your request.  You must initiate a multipart upload before you can upload any part. In response to your initiate request. Amazon S3 returns a unique identifier, the upload ID, that you must include in your upload part request. For more information about using the UploadPartCopy operation, see the following:   For conceptual information about multipart uploads, see Uploading Objects Using Multipart Upload in the Amazon S3 User Guide.   For information about permissions required to use the multipart upload API, see Multipart Upload and Permissions in the Amazon S3 User Guide.   For information about copying objects using a single atomic action vs. the multipart upload, see Operations on Objects in the Amazon S3 User Guide.   For information about using server-side encryption with customer-provided encryption keys with the UploadPartCopy operation, see CopyObject and UploadPart.   Note the following additional considerations about the request headers x-amz-copy-source-if-match, x-amz-copy-source-if-none-match, x-amz-copy-source-if-unmodified-since, and x-amz-copy-source-if-modified-since:      Consideration 1 - If both of the x-amz-copy-source-if-match and x-amz-copy-source-if-unmodified-since headers are present in the request as follows:  x-amz-copy-source-if-match condition evaluates to true, and;  x-amz-copy-source-if-unmodified-since condition evaluates to false; Amazon S3 returns 200 OK and copies the data.     Consideration 2 - If both of the x-amz-copy-source-if-none-match and x-amz-copy-source-if-modified-since headers are present in the request as follows:  x-amz-copy-source-if-none-match condition evaluates to false, and;  x-amz-copy-source-if-modified-since condition evaluates to true; Amazon S3 returns 412 Precondition Failed response code.     Versioning  If your bucket has versioning enabled, you could have multiple versions of the same object. By default, x-amz-copy-source identifies the current version of the object to copy. If the current version is a delete marker and you don't specify a versionId in the x-amz-copy-source, Amazon S3 returns a 404 error, because the object does not exist. If you specify versionId in the x-amz-copy-source and the versionId is a delete marker, Amazon S3 returns an HTTP 400 error, because you are not allowed to specify a delete marker as a version for the x-amz-copy-source.  You can optionally specify a specific version of the source object to copy by adding the versionId subresource as shown in the following example:  x-amz-copy-source: /bucket/object?versionId=version id   Special Errors       Code: NoSuchUpload     Cause: The specified multipart upload does not exist. The upload ID might be invalid, or the multipart upload might have been aborted or completed.     HTTP Status Code: 404 Not Found         Code: InvalidRequest     Cause: The specified copy source is not supported as a byte-range copy source.     HTTP Status Code: 400 Bad Request       Related Resources     CreateMultipartUpload     UploadPart     CompleteMultipartUpload     AbortMultipartUpload     ListParts     ListMultipartUploads

    Args:
        bucket(str): The bucket name. When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. When using this action with Amazon S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When using this action using S3 on Outposts through the AWS SDKs, you provide the Outposts bucket ARN in place of the bucket name. For more information about S3 on Outposts ARNs, see Using S3 on Outposts in the Amazon S3 User Guide.
        copy_source(str): Specifies the source object for the copy operation. You specify the value in one of two formats, depending on whether you want to access the source object through an access point:   For objects not accessed through an access point, specify the name of the source bucket and key of the source object, separated by a slash (/). For example, to copy the object reports/january.pdf from the bucket awsexamplebucket, use awsexamplebucket/reports/january.pdf. The value must be URL encoded.   For objects accessed through access points, specify the Amazon Resource Name (ARN) of the object as accessed through the access point, in the format arn:aws:s3:<Region>:<account-id>:accesspoint/<access-point-name>/object/<key>. For example, to copy the object reports/january.pdf through access point my-access-point owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/reports/january.pdf. The value must be URL encoded.  Amazon S3 supports copy operations using access points only when the source and destination buckets are in the same AWS Region.  Alternatively, for objects accessed through Amazon S3 on Outposts, specify the ARN of the object as accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/object/<key>. For example, to copy the object reports/january.pdf through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/object/reports/january.pdf. The value must be URL encoded.    To copy a specific version of an object, append ?versionId=<version-id> to the value (for example, awsexamplebucket/reports/january.pdf?versionId=QUpfdndhfd8438MNFDN93jdnJFkdmqnh893). If you don't specify a version ID, Amazon S3 copies the latest version of the source object.
        copy_source_if_match(str, optional): Copies the object if its entity tag (ETag) matches the specified tag. Defaults to None.
        copy_source_if_modified_since(str, optional): Copies the object if it has been modified since the specified time. Defaults to None.
        copy_source_if_none_match(str, optional): Copies the object if its entity tag (ETag) is different than the specified ETag. Defaults to None.
        copy_source_if_unmodified_since(str, optional): Copies the object if it hasn't been modified since the specified time. Defaults to None.
        copy_source_range(str, optional): The range of bytes to copy from the source object. The range value must use the form bytes=first-last, where the first and last are the zero-based byte offsets to copy. For example, bytes=0-9 indicates that you want to copy the first 10 bytes of the source. You can copy a range only if the source object is greater than 5 MB. Defaults to None.
        key(str): Object key for which the multipart upload was initiated.
        part_number(int): Part number of part being copied. This is a positive integer between 1 and 10,000.
        upload_id(str): Upload ID identifying the multipart upload whose part is being copied.
        sse_customer_algorithm(str, optional): Specifies the algorithm to use to when encrypting the object (for example, AES256). Defaults to None.
        sse_customer_key(str, optional): Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header. This must be the same encryption key specified in the initiate multipart upload request. Defaults to None.
        sse_customer_key_md5(str, optional): Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. Defaults to None.
        copy_source_sse_customer_algorithm(str, optional): Specifies the algorithm to use when decrypting the source object (for example, AES256). Defaults to None.
        copy_source_sse_customer_key(str, optional): Specifies the customer-provided encryption key for Amazon S3 to use to decrypt the source object. The encryption key provided in this header must be one that was used when the source object was created. Defaults to None.
        copy_source_sse_customer_key_md5(str, optional): Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. Defaults to None.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected destination bucket owner. If the destination bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
        expected_source_bucket_owner(str, optional): The account ID of the expected source bucket owner. If the source bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.part.copy.upload(
                ctx, bucket=value, copy_source=value, key=value, part_number=value, upload_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.part.copy.upload bucket=value, copy_source=value, key=value, part_number=value, upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="upload_part_copy",
        op_kwargs={
            "Bucket": bucket,
            "CopySource": copy_source,
            "CopySourceIfMatch": copy_source_if_match,
            "CopySourceIfModifiedSince": copy_source_if_modified_since,
            "CopySourceIfNoneMatch": copy_source_if_none_match,
            "CopySourceIfUnmodifiedSince": copy_source_if_unmodified_since,
            "CopySourceRange": copy_source_range,
            "Key": key,
            "PartNumber": part_number,
            "UploadId": upload_id,
            "SSECustomerAlgorithm": sse_customer_algorithm,
            "SSECustomerKey": sse_customer_key,
            "SSECustomerKeyMD5": sse_customer_key_md5,
            "CopySourceSSECustomerAlgorithm": copy_source_sse_customer_algorithm,
            "CopySourceSSECustomerKey": copy_source_sse_customer_key,
            "CopySourceSSECustomerKeyMD5": copy_source_sse_customer_key_md5,
            "RequestPayer": request_payer,
            "ExpectedBucketOwner": expected_bucket_owner,
            "ExpectedSourceBucketOwner": expected_source_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, app_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the validation configuration for the specified application.

    Args:
        app_id(str): The ID of the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.validation.configuration.delete(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.validation.configuration.delete app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="delete_app_validation_configuration",
        op_kwargs={"appId": app_id},
    )


async def get(hub, ctx, app_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a configuration for validating an application.

    Args:
        app_id(str): The ID of the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.validation.configuration.get(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.validation.configuration.get app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="get_app_validation_configuration",
        op_kwargs={"appId": app_id},
    )


async def put(
    hub,
    ctx,
    app_id: str,
    app_validation_configurations: List = None,
    server_group_validation_configurations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a validation configuration for the specified application.

    Args:
        app_id(str): The ID of the application.
        app_validation_configurations(List, optional): The configuration for application validation. Defaults to None.
        server_group_validation_configurations(List, optional): The configuration for instance validation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.validation.configuration.put(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.validation.configuration.put app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="put_app_validation_configuration",
        op_kwargs={
            "appId": app_id,
            "appValidationConfigurations": app_validation_configurations,
            "serverGroupValidationConfigurations": server_group_validation_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    network_interface_id: str = None,
    network_load_balancer_arn: str = None,
    description: str = None,
    tag_specifications: List = None,
    dry_run: bool = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a target for your Traffic Mirror session. A Traffic Mirror target is the destination for mirrored traffic. The Traffic Mirror source and the Traffic Mirror target (monitoring appliances) can be in the same VPC, or in different VPCs connected via VPC peering or a transit gateway. A Traffic Mirror target can be a network interface, or a Network Load Balancer. To use the target in a Traffic Mirror session, use CreateTrafficMirrorSession.

    Args:
        network_interface_id(str, optional): The network interface ID that is associated with the target. Defaults to None.
        network_load_balancer_arn(str, optional): The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the target. Defaults to None.
        description(str, optional): The description of the Traffic Mirror target. Defaults to None.
        tag_specifications(List, optional): The tags to assign to the Traffic Mirror target. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.target.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.target.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_traffic_mirror_target",
        op_kwargs={
            "NetworkInterfaceId": network_interface_id,
            "NetworkLoadBalancerArn": network_load_balancer_arn,
            "Description": description,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, traffic_mirror_target_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Traffic Mirror target. You cannot delete a Traffic Mirror target that is in use by a Traffic Mirror session.

    Args:
        traffic_mirror_target_id(str): The ID of the Traffic Mirror target.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.target.delete(
                ctx, traffic_mirror_target_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.target.delete traffic_mirror_target_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_traffic_mirror_target",
        op_kwargs={
            "TrafficMirrorTargetId": traffic_mirror_target_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    traffic_mirror_target_ids: List = None,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Information about one or more Traffic Mirror targets.

    Args:
        traffic_mirror_target_ids(List, optional): The ID of the Traffic Mirror targets. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    description: The Traffic Mirror target description.    network-interface-id: The ID of the Traffic Mirror session network interface.    network-load-balancer-arn: The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the session.    owner-id: The ID of the account that owns the Traffic Mirror session.    traffic-mirror-target-id: The ID of the Traffic Mirror target.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.target.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.target.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_traffic_mirror_targets",
        op_kwargs={
            "TrafficMirrorTargetIds": traffic_mirror_target_ids,
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update_multiple(
    hub, ctx, endpoint_name: str, desired_weights_and_capacities: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates variant weight of one or more variants associated with an existing endpoint, or capacity of one variant associated with an existing endpoint. When it receives the request, Amazon SageMaker sets the endpoint status to Updating. After updating the endpoint, it sets the status to InService. To check the status of an endpoint, use the DescribeEndpoint API.

    Args:
        endpoint_name(str): The name of an existing Amazon SageMaker endpoint.
        desired_weights_and_capacities(List): An object that provides new capacity and weight values for a variant.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.weight_and_capacity.update_multiple(
                ctx, endpoint_name=value, desired_weights_and_capacities=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.weight_and_capacity.update_multiple endpoint_name=value, desired_weights_and_capacities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_endpoint_weights_and_capacities",
        op_kwargs={
            "EndpointName": endpoint_name,
            "DesiredWeightsAndCapacities": desired_weights_and_capacities,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    global_network_id: str,
    device_id: str = None,
    link_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the link associations for a device or a link. Either the device ID or the link ID must be specified.

    Args:
        global_network_id(str): The ID of the global network.
        device_id(str, optional): The ID of the device. Defaults to None.
        link_id(str, optional): The ID of the link. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.link.association.get_all(
                ctx, global_network_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.link.association.get_all global_network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="get_link_associations",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "DeviceId": device_id,
            "LinkId": link_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "termination_policy_type"


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Describes the termination policies supported by Amazon EC2 Auto Scaling. For more information, see Controlling which Auto Scaling instances terminate during scale in in the Amazon EC2 Auto Scaling User Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.termination_policy_type_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.termination_policy_type.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_termination_policy_types",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub, ctx, source: Dict, sinks: List = None, location: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates mappings.

    Args:
        source(Dict): Specifies the source table.
        sinks(List, optional): A list of target tables. Defaults to None.
        location(Dict, optional): Parameters for the mapping. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.mapping.get(ctx, source=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.mapping.get source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_mapping",
        op_kwargs={"Source": source, "Sinks": sinks, "Location": location},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, resolver_query_log_config_id: str, resource_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Associates an Amazon VPC with a specified query logging configuration. Route 53 Resolver logs DNS queries that originate in all of the Amazon VPCs that are associated with a specified query logging configuration. To associate more than one VPC with a configuration, submit one AssociateResolverQueryLogConfig request for each VPC.  The VPCs that you associate with a query logging configuration must be in the same Region as the configuration.  To remove a VPC from a query logging configuration, see DisassociateResolverQueryLogConfig.

    Args:
        resolver_query_log_config_id(str): The ID of the query logging configuration that you want to associate a VPC with.
        resource_id(str): The ID of an Amazon VPC that you want this query logging configuration to log queries for.  The VPCs and the query logging configuration must be in the same Region. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.init.associate(
                ctx, resolver_query_log_config_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.init.associate resolver_query_log_config_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="associate_resolver_query_log_config",
        op_kwargs={
            "ResolverQueryLogConfigId": resolver_query_log_config_id,
            "ResourceId": resource_id,
        },
    )


async def create(
    hub,
    ctx,
    name: str,
    destination_arn: str,
    creator_request_id: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs. Resolver can log queries only for VPCs that are in the same Region as the query logging configuration. To specify which VPCs you want to log queries for, you use AssociateResolverQueryLogConfig. For more information, see AssociateResolverQueryLogConfig.  You can optionally use AWS Resource Access Manager (AWS RAM) to share a query logging configuration with other AWS accounts. The other accounts can then associate VPCs with the configuration. The query logs that Resolver creates for a configuration include all DNS queries that originate in all VPCs that are associated with the configuration.

    Args:
        name(str): The name that you want to give the query logging configuration.
        destination_arn(str): The ARN of the resource that you want Resolver to send query logs. You can send query logs to an S3 bucket, a CloudWatch Logs log group, or a Kinesis Data Firehose delivery stream. Examples of valid values include the following:    S3 bucket:   arn:aws:s3:::examplebucket  You can optionally append a file prefix to the end of the ARN.  arn:aws:s3:::examplebucket/development/     CloudWatch Logs log group:   arn:aws:logs:us-west-1:123456789012:log-group:/mystack-testgroup-12ABC1AB12A1:*     Kinesis Data Firehose delivery stream:  arn:aws:kinesis:us-east-2:0123456789:stream/my_stream_name   .
        creator_request_id(str): A unique string that identifies the request and that allows failed requests to be retried without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp. .
        tags(List, optional): A list of the tag keys and values that you want to associate with the query logging configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.init.create(
                ctx, name=value, destination_arn=value, creator_request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.init.create name=value, destination_arn=value, creator_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="create_resolver_query_log_config",
        op_kwargs={
            "Name": name,
            "DestinationArn": destination_arn,
            "CreatorRequestId": creator_request_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, resolver_query_log_config_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a query logging configuration. When you delete a configuration, Resolver stops logging DNS queries for all of the Amazon VPCs that are associated with the configuration. This also applies if the query logging configuration is shared with other AWS accounts, and the other accounts have associated VPCs with the shared configuration. Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. See DisassociateResolverQueryLogConfig. If you used Resource Access Manager (RAM) to share a query logging configuration with other accounts, you must stop sharing the configuration before you can delete a configuration. The accounts that you shared the configuration with can first disassociate VPCs that they associated with the configuration, but that's not necessary. If you stop sharing the configuration, those VPCs are automatically disassociated from the configuration.

    Args:
        resolver_query_log_config_id(str): The ID of the query logging configuration that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.init.delete(
                ctx, resolver_query_log_config_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.init.delete resolver_query_log_config_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="delete_resolver_query_log_config",
        op_kwargs={"ResolverQueryLogConfigId": resolver_query_log_config_id},
    )


async def disassociate(
    hub, ctx, resolver_query_log_config_id: str, resource_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a VPC from a query logging configuration.  Before you can delete a query logging configuration, you must first disassociate all VPCs from the configuration. If you used AWS Resource Access Manager (AWS RAM) to share a query logging configuration with other accounts, VPCs can be disassociated from the configuration in the following ways:   The accounts that you shared the configuration with can disassociate VPCs from the configuration.   You can stop sharing the configuration.

    Args:
        resolver_query_log_config_id(str): The ID of the query logging configuration that you want to disassociate a specified VPC from.
        resource_id(str): The ID of the Amazon VPC that you want to disassociate from a specified query logging configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.init.disassociate(
                ctx, resolver_query_log_config_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.init.disassociate resolver_query_log_config_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="disassociate_resolver_query_log_config",
        op_kwargs={
            "ResolverQueryLogConfigId": resolver_query_log_config_id,
            "ResourceId": resource_id,
        },
    )


async def get(hub, ctx, resolver_query_log_config_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.

    Args:
        resolver_query_log_config_id(str): The ID of the Resolver query logging configuration that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.init.get(
                ctx, resolver_query_log_config_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.init.get resolver_query_log_config_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_query_log_config",
        op_kwargs={"ResolverQueryLogConfigId": resolver_query_log_config_id},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about the specified query logging configurations. Each configuration defines where you want Resolver to save DNS query logs and specifies the VPCs that you want to log queries for.

    Args:
        max_results(int, optional): The maximum number of query logging configurations that you want to return in the response to a ListResolverQueryLogConfigs request. If you don't specify a value for MaxResults, Resolver returns up to 100 query logging configurations. . Defaults to None.
        next_token(str, optional): For the first ListResolverQueryLogConfigs request, omit this value. If there are more than MaxResults query logging configurations that match the values that you specify for Filters, you can submit another ListResolverQueryLogConfigs request to get the next group of configurations. In the next request, specify the value of NextToken from the previous response. . Defaults to None.
        filters(List, optional): An optional specification to return a subset of query logging configurations.  If you submit a second or subsequent ListResolverQueryLogConfigs request and specify the NextToken parameter, you must use the same values for Filters, if any, as in the previous request. . Defaults to None.
        sort_by(str, optional): The element that you want Resolver to sort query logging configurations by.   If you submit a second or subsequent ListResolverQueryLogConfigs request and specify the NextToken parameter, you must use the same value for SortBy, if any, as in the previous request.  Valid values include the following elements:    Arn: The ARN of the query logging configuration    AssociationCount: The number of VPCs that are associated with the specified configuration     CreationTime: The date and time that Resolver returned when the configuration was created    CreatorRequestId: The value that was specified for CreatorRequestId when the configuration was created    DestinationArn: The location that logs are sent to    Id: The ID of the configuration    Name: The name of the configuration    OwnerId: The AWS account number of the account that created the configuration    ShareStatus: Whether the configuration is shared with other AWS accounts or shared with the current account by another AWS account. Sharing is configured through AWS Resource Access Manager (AWS RAM).    Status: The current status of the configuration. Valid values include the following:    CREATING: Resolver is creating the query logging configuration.    CREATED: The query logging configuration was successfully created. Resolver is logging queries that originate in the specified VPC.    DELETING: Resolver is deleting this query logging configuration.    FAILED: Resolver either couldn't create or couldn't delete the query logging configuration. Here are two common causes:   The specified destination (for example, an Amazon S3 bucket) was deleted.   Permissions don't allow sending logs to the destination.      . Defaults to None.
        sort_order(str, optional): If you specified a value for SortBy, the order that you want query logging configurations to be listed in, ASCENDING or DESCENDING.  If you submit a second or subsequent ListResolverQueryLogConfigs request and specify the NextToken parameter, you must use the same value for SortOrder, if any, as in the previous request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_resolver_query_log_configs",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    destination_cidr_block: str,
    target_vpc_subnet_id: str,
    description: str = None,
    client_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a route to a network to a Client VPN endpoint. Each Client VPN endpoint has a route table that describes the available destination network routes. Each route in the route table specifies the path for traﬃc to speciﬁc resources or networks.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint to which to add the route.
        destination_cidr_block(str): The IPv4 address range, in CIDR notation, of the route destination. For example:   To add a route for Internet access, enter 0.0.0.0/0    To add a route for a peered VPC, enter the peered VPC's IPv4 CIDR range   To add a route for an on-premises network, enter the AWS Site-to-Site VPN connection's IPv4 CIDR range   To add a route for the local network, enter the client CIDR range  .
        target_vpc_subnet_id(str): The ID of the subnet through which you want to route traffic. The specified subnet must be an existing target network of the Client VPN endpoint. Alternatively, if you're adding a route for the local network, specify local.
        description(str, optional): A brief description of the route. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.route.create(
                ctx,
                client_vpn_endpoint_id=value,
                destination_cidr_block=value,
                target_vpc_subnet_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.route.create client_vpn_endpoint_id=value, destination_cidr_block=value, target_vpc_subnet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_client_vpn_route",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "DestinationCidrBlock": destination_cidr_block,
            "TargetVpcSubnetId": target_vpc_subnet_id,
            "Description": description,
            "ClientToken": client_token,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    destination_cidr_block: str,
    target_vpc_subnet_id: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a route from a Client VPN endpoint. You can only delete routes that you manually added using the CreateClientVpnRoute action. You cannot delete routes that were automatically added when associating a subnet. To remove routes that have been automatically added, disassociate the target subnet from the Client VPN endpoint.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint from which the route is to be deleted.
        target_vpc_subnet_id(str, optional): The ID of the target subnet used by the route. Defaults to None.
        destination_cidr_block(str): The IPv4 address range, in CIDR notation, of the route to be deleted.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.route.delete(
                ctx, client_vpn_endpoint_id=value, destination_cidr_block=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.route.delete client_vpn_endpoint_id=value, destination_cidr_block=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_client_vpn_route",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "TargetVpcSubnetId": target_vpc_subnet_id,
            "DestinationCidrBlock": destination_cidr_block,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the routes for the specified Client VPN endpoint.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint.
        filters(List, optional): One or more filters. Filter names and values are case-sensitive.    destination-cidr - The CIDR of the route destination.    origin - How the route was associated with the Client VPN endpoint (associate | add-route).    target-subnet - The ID of the subnet through which traffic is routed.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.route.describe_all(
                ctx, client_vpn_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.route.describe_all client_vpn_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_client_vpn_routes",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, stream_name: str, shard_count: int) -> None:
    r"""
    **Autogenerated function**

    Creates a Kinesis data stream. A stream captures and transports data records that are continuously emitted from different data sources or producers. Scale-out within a stream is explicitly supported by means of shards, which are uniquely identified groups of data records in a stream. You specify and control the number of shards that a stream is composed of. Each shard can support reads up to five transactions per second, up to a maximum data read total of 2 MiB per second. Each shard can support writes up to 1,000 records per second, up to a maximum data write total of 1 MiB per second. If the amount of data input increases or decreases, you can add or remove shards. The stream name identifies the stream. The name is scoped to the AWS account used by the application. It is also scoped by AWS Region. That is, two streams in two different accounts can have the same name, and two streams in the same account, but in two different Regions, can have the same name.  CreateStream is an asynchronous operation. Upon receiving a CreateStream request, Kinesis Data Streams immediately returns and sets the stream status to CREATING. After the stream is created, Kinesis Data Streams sets the stream status to ACTIVE. You should perform read and write operations only on an ACTIVE stream.  You receive a LimitExceededException when making a CreateStream request when you try to do one of the following:   Have more than five streams in the CREATING state at any point in time.   Create more shards than are authorized for your account.   For the default shard limit for an AWS account, see Amazon Kinesis Data Streams Limits in the Amazon Kinesis Data Streams Developer Guide. To increase this limit, contact AWS Support. You can use DescribeStream to check the stream status, which is returned in StreamStatus.  CreateStream has a limit of five transactions per second per account.

    Args:
        stream_name(str): A name to identify the stream. The stream name is scoped to the AWS account used by the application that creates the stream. It is also scoped by AWS Region. That is, two streams in two different AWS accounts can have the same name. Two streams in the same AWS account but in two different Regions can also have the same name.
        shard_count(int): The number of shards that the stream will use. The throughput of the stream is a function of the number of shards; more shards are required for greater provisioned throughput.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.init.create(
                ctx, stream_name=value, shard_count=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.init.create stream_name=value, shard_count=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="create_stream",
        op_kwargs={"StreamName": stream_name, "ShardCount": shard_count},
    )


async def delete(
    hub, ctx, stream_name: str, enforce_consumer_deletion: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes a Kinesis data stream and all its shards and data. You must shut down any applications that are operating on the stream before you delete the stream. If an application attempts to operate on a deleted stream, it receives the exception ResourceNotFoundException. If the stream is in the ACTIVE state, you can delete it. After a DeleteStream request, the specified stream is in the DELETING state until Kinesis Data Streams completes the deletion.  Note: Kinesis Data Streams might continue to accept data read and write operations, such as PutRecord, PutRecords, and GetRecords, on a stream in the DELETING state until the stream deletion is complete. When you delete a stream, any shards in that stream are also deleted, and any tags are dissociated from the stream. You can use the DescribeStream operation to check the state of the stream, which is returned in StreamStatus.  DeleteStream has a limit of five transactions per second per account.

    Args:
        stream_name(str): The name of the stream to delete.
        enforce_consumer_deletion(bool, optional): If this parameter is unset (null) or if you set it to false, and the stream has registered consumers, the call to DeleteStream fails with a ResourceInUseException. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.init.delete(ctx, stream_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.init.delete stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="delete_stream",
        op_kwargs={
            "StreamName": stream_name,
            "EnforceConsumerDeletion": enforce_consumer_deletion,
        },
    )


async def describe(
    hub, ctx, stream_name: str, limit: int = None, exclusive_start_shard_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Kinesis data stream. The information returned includes the stream name, Amazon Resource Name (ARN), creation time, enhanced metric configuration, and shard map. The shard map is an array of shard objects. For each shard object, there is the hash key and sequence number ranges that the shard spans, and the IDs of any earlier shards that played in a role in creating the shard. Every record ingested in the stream is identified by a sequence number, which is assigned when the record is put into the stream. You can limit the number of shards returned by each call. For more information, see Retrieving Shards from a Stream in the Amazon Kinesis Data Streams Developer Guide. There are no guarantees about the chronological order shards returned. To process shards in chronological order, use the ID of the parent shard to track the lineage to the oldest shard. This operation has a limit of 10 transactions per second per account.

    Args:
        stream_name(str): The name of the stream to describe.
        limit(int, optional): The maximum number of shards to return in a single call. The default value is 100. If you specify a value greater than 100, at most 100 shards are returned. Defaults to None.
        exclusive_start_shard_id(str, optional): The shard ID of the shard to start with. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.init.describe(ctx, stream_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.init.describe stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="describe_stream",
        op_kwargs={
            "StreamName": stream_name,
            "Limit": limit,
            "ExclusiveStartShardId": exclusive_start_shard_id,
        },
    )


async def list_all(
    hub, ctx, limit: int = None, exclusive_start_stream_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your Kinesis data streams. The number of streams may be too large to return from a single call to ListStreams. You can limit the number of returned streams using the Limit parameter. If you do not specify a value for the Limit parameter, Kinesis Data Streams uses the default limit, which is currently 10. You can detect if there are more streams available to list by using the HasMoreStreams flag from the returned output. If there are more streams available, you can request more streams by using the name of the last stream returned by the ListStreams request in the ExclusiveStartStreamName parameter in a subsequent request to ListStreams. The group of stream names returned by the subsequent request is then added to the list. You can continue this process until all the stream names have been collected in the list.   ListStreams has a limit of five transactions per second per account.

    Args:
        limit(int, optional): The maximum number of streams to list. Defaults to None.
        exclusive_start_stream_name(str, optional): The name of the stream to start the list with. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="list_streams",
        op_kwargs={
            "Limit": limit,
            "ExclusiveStartStreamName": exclusive_start_stream_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def change(
    hub, ctx, previous_password: str, proposed_password: str, access_token: str
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the password for a specified user in a user pool.

    Args:
        previous_password(str): The old password.
        proposed_password(str): The new password.
        access_token(str): The access token.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.password.change(
                ctx, previous_password=value, proposed_password=value, access_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.password.change previous_password=value, proposed_password=value, access_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="change_password",
        op_kwargs={
            "PreviousPassword": previous_password,
            "ProposedPassword": proposed_password,
            "AccessToken": access_token,
        },
    )


async def forgot(
    hub,
    ctx,
    client_id: str,
    username: str,
    secret_hash: str = None,
    user_context_data: Dict = None,
    analytics_metadata: Dict = None,
    client_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Calling this API causes a message to be sent to the end user with a confirmation code that is required to change the user's password. For the Username parameter, you can use the username or user alias. The method used to send the confirmation code is sent according to the specified AccountRecoverySetting. For more information, see Recovering User Accounts in the Amazon Cognito Developer Guide. If neither a verified phone number nor a verified email exists, an InvalidParameterException is thrown. To use the confirmation code for resetting the password, call ConfirmForgotPassword.  This action might generate an SMS text message. Starting June 1, 2021, U.S. telecom carriers require that you register an origination phone number before you can send SMS messages to U.S. phone numbers. If you use SMS text messages in Amazon Cognito, you must register a phone number with Amazon Pinpoint. Cognito will use the the registered number automatically. Otherwise, Cognito users that must receive SMS messages might be unable to sign up, activate their accounts, or sign in. If you have never used SMS text messages with Amazon Cognito or any other Amazon Web Service, Amazon SNS might place your account in SMS sandbox. In  sandbox mode , you’ll have limitations, such as sending messages to only verified phone numbers. After testing in the sandbox environment, you can move out of the SMS sandbox and into production. For more information, see  SMS message settings for Cognito User Pools in the Amazon Cognito Developer Guide.

    Args:
        client_id(str): The ID of the client associated with the user pool.
        secret_hash(str, optional): A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message. Defaults to None.
        user_context_data(Dict, optional): Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security. Defaults to None.
        username(str): The user name of the user for whom you want to enter a code to reset a forgotten password.
        analytics_metadata(Dict, optional): The Amazon Pinpoint analytics metadata for collecting metrics for ForgotPassword calls. Defaults to None.
        client_metadata(Dict, optional): A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.  You create custom workflows by assigning Lambda functions to user pool triggers. When you use the ForgotPassword API action, Amazon Cognito invokes any functions that are assigned to the following triggers: pre sign-up, custom message, and user migration. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a clientMetadata attribute, which provides the data that you assigned to the ClientMetadata parameter in your ForgotPassword request. In your function code in Lambda, you can process the clientMetadata value to enhance your workflow for your specific needs. For more information, see Customizing User Pool Workflows with Lambda Triggers in the Amazon Cognito Developer Guide.  Take the following limitations into consideration when you use the ClientMetadata parameter:   Amazon Cognito does not store the ClientMetadata value. This data is available only to Lambda triggers that are assigned to a user pool to support custom workflows. If your user pool configuration does not include triggers, the ClientMetadata parameter serves no purpose.   Amazon Cognito does not validate the ClientMetadata value.   Amazon Cognito does not encrypt the the ClientMetadata value, so don't use it to provide sensitive information.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.password.forgot(
                ctx, client_id=value, username=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.password.forgot client_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="forgot_password",
        op_kwargs={
            "ClientId": client_id,
            "SecretHash": secret_hash,
            "UserContextData": user_context_data,
            "Username": username,
            "AnalyticsMetadata": analytics_metadata,
            "ClientMetadata": client_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, assignment_id: str, question_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

     The GetFileUploadURL operation generates and returns a temporary URL. You use the temporary URL to retrieve a file uploaded by a Worker as an answer to a FileUploadAnswer question for a HIT. The temporary URL is generated the instant the GetFileUploadURL operation is called, and is valid for 60 seconds. You can get a temporary file upload URL any time until the HIT is disposed. After the HIT is disposed, any uploaded files are deleted, and cannot be retrieved. Pending Deprecation on December 12, 2017. The Answer Specification structure will no longer support the FileUploadAnswer element to be used for the QuestionForm data structure. Instead, we recommend that Requesters who want to create HITs asking Workers to upload files to use Amazon S3.

    Args:
        assignment_id(str): The ID of the assignment that contains the question with a FileUploadAnswer.
        question_identifier(str): The identifier of the question with a FileUploadAnswer, as specified in the QuestionForm of the HIT.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.file_upload_url.get(
                ctx, assignment_id=value, question_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.file_upload_url.get assignment_id=value, question_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="get_file_upload_url",
        op_kwargs={
            "AssignmentId": assignment_id,
            "QuestionIdentifier": question_identifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, tag_key: str, tag_values: List, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a tag with the specified name and values.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        tag_key(str): The key-name for the tag.
        tag_values(List): A list of possible values an attribute can take.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.lf_tag.create(
                ctx, tag_key=value, tag_values=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.lf_tag.create tag_key=value, tag_values=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="create_lf_tag",
        op_kwargs={"CatalogId": catalog_id, "TagKey": tag_key, "TagValues": tag_values},
    )


async def delete(hub, ctx, tag_key: str, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified tag key name. If the attribute key does not exist or the tag does not exist, then the operation will not do anything. If the attribute key exists, then the operation checks if any resources are tagged with this attribute key, if yes, the API throws a 400 Exception with the message "Delete not allowed" as the tag key is still attached with resources. You can consider untagging resources with this tag key.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        tag_key(str): The key-name for the tag to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.lf_tag.delete(ctx, tag_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.lf_tag.delete tag_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="delete_lf_tag",
        op_kwargs={"CatalogId": catalog_id, "TagKey": tag_key},
    )


async def get(hub, ctx, tag_key: str, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a tag definition.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        tag_key(str): The key-name for the tag.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.lf_tag.get(ctx, tag_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.lf_tag.get tag_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="get_lf_tag",
        op_kwargs={"CatalogId": catalog_id, "TagKey": tag_key},
    )


async def list_all(
    hub,
    ctx,
    catalog_id: str = None,
    resource_share_type: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists tags that the requester has permission to view.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        resource_share_type(str, optional): If resource share type is ALL, returns both in-account tags and shared tags that the requester has permission to view. If resource share type is FOREIGN, returns all share tags that the requester can view. If no resource share type is passed, lists tags in the given catalog ID that the requester has permission to view. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): A continuation token, if this is not the first call to retrieve this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.lf_tag.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.lf_tag.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="list_lf_tags",
        op_kwargs={
            "CatalogId": catalog_id,
            "ResourceShareType": resource_share_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    tag_key: str,
    catalog_id: str = None,
    tag_values_to_delete: List = None,
    tag_values_to_add: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the list of possible values for the specified tag key. If the tag does not exist, the operation throws an EntityNotFoundException. The values in the delete key values will be deleted from list of possible values. If any value in the delete key values is attached to a resource, then API errors out with a 400 Exception - "Update not allowed". Untag the attribute before deleting the tag key's value.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        tag_key(str): The key-name for the tag for which to add or delete values.
        tag_values_to_delete(List, optional): A list of tag values to delete from the tag. Defaults to None.
        tag_values_to_add(List, optional): A list of tag values to add from the tag. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.lf_tag.update(ctx, tag_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.lf_tag.update tag_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="update_lf_tag",
        op_kwargs={
            "CatalogId": catalog_id,
            "TagKey": tag_key,
            "TagValuesToDelete": tag_values_to_delete,
            "TagValuesToAdd": tag_values_to_add,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    ota_update_id: str,
    targets: List,
    files: List,
    role_arn: str,
    description: str = None,
    protocols: List = None,
    target_selection: str = None,
    aws_job_executions_rollout_config: Dict = None,
    aws_job_presigned_url_config: Dict = None,
    aws_job_abort_config: Dict = None,
    aws_job_timeout_config: Dict = None,
    additional_parameters: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AWS IoT OTAUpdate on a target group of things or groups.

    Args:
        ota_update_id(str): The ID of the OTA update to be created.
        description(str, optional): The description of the OTA update. Defaults to None.
        targets(List): The devices targeted to receive OTA updates.
        protocols(List, optional): The protocol used to transfer the OTA update image. Valid values are [HTTP], [MQTT], [HTTP, MQTT]. When both HTTP and MQTT are specified, the target device can choose the protocol. Defaults to None.
        target_selection(str, optional): Specifies whether the update will continue to run (CONTINUOUS), or will be complete after all the things specified as targets have completed the update (SNAPSHOT). If continuous, the update may also be run on a thing when a change is detected in a target. For example, an update will run on a thing when the thing is added to a target group, even after the update was completed by all things originally in the group. Valid values: CONTINUOUS | SNAPSHOT. Defaults to None.
        aws_job_executions_rollout_config(Dict, optional): Configuration for the rollout of OTA updates. Defaults to None.
        aws_job_presigned_url_config(Dict, optional): Configuration information for pre-signed URLs. Defaults to None.
        aws_job_abort_config(Dict, optional): The criteria that determine when and how a job abort takes place. Defaults to None.
        aws_job_timeout_config(Dict, optional): Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to IN_PROGRESS. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to TIMED_OUT. Defaults to None.
        files(List): The files to be streamed by the OTA update.
        role_arn(str): The IAM role that grants AWS IoT access to the Amazon S3, AWS IoT jobs and AWS Code Signing resources to create an OTA update job.
        additional_parameters(Dict, optional): A list of additional OTA update parameters which are name-value pairs. Defaults to None.
        tags(List, optional): Metadata which can be used to manage updates. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ota_update.create(
                ctx, ota_update_id=value, targets=value, files=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ota_update.create ota_update_id=value, targets=value, files=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_ota_update",
        op_kwargs={
            "otaUpdateId": ota_update_id,
            "description": description,
            "targets": targets,
            "protocols": protocols,
            "targetSelection": target_selection,
            "awsJobExecutionsRolloutConfig": aws_job_executions_rollout_config,
            "awsJobPresignedUrlConfig": aws_job_presigned_url_config,
            "awsJobAbortConfig": aws_job_abort_config,
            "awsJobTimeoutConfig": aws_job_timeout_config,
            "files": files,
            "roleArn": role_arn,
            "additionalParameters": additional_parameters,
            "tags": tags,
        },
    )


async def delete(
    hub,
    ctx,
    ota_update_id: str,
    delete_stream: bool = None,
    force_delete_aws_job: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Delete an OTA update.

    Args:
        ota_update_id(str): The ID of the OTA update to delete.
        delete_stream(bool, optional): When true, the stream created by the OTAUpdate process is deleted when the OTA update is deleted. Ignored if the stream specified in the OTAUpdate is supplied by the user. Defaults to None.
        force_delete_aws_job(bool, optional): When true, deletes the AWS job created by the OTAUpdate process even if it is "IN_PROGRESS". Otherwise, if the job is not in a terminal state ("COMPLETED" or "CANCELED") an exception will occur. The default is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ota_update.delete(ctx, ota_update_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ota_update.delete ota_update_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_ota_update",
        op_kwargs={
            "otaUpdateId": ota_update_id,
            "deleteStream": delete_stream,
            "forceDeleteAWSJob": force_delete_aws_job,
        },
    )


async def get(hub, ctx, ota_update_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets an OTA update.

    Args:
        ota_update_id(str): The OTA update ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ota_update.get(ctx, ota_update_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ota_update.get ota_update_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_ota_update",
        op_kwargs={"otaUpdateId": ota_update_id},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    ota_update_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists OTA updates.

    Args:
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        next_token(str, optional): A token used to retrieve the next set of results. Defaults to None.
        ota_update_status(str, optional): The OTA update job status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.ota_update.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.ota_update.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_ota_updates",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "otaUpdateStatus": ota_update_status,
        },
    )
